@@ -2,7 +2,8 @@ use crate::{
     ens,
     pubsub::{PubsubClient, SubscriptionStream},
     stream::{FilterWatcher, DEFAULT_POLL_INTERVAL},
-    FeeHistory, FromErr, Http as HttpProvider, JsonRpcClient, MockProvider, PendingTransaction,
+    FeeHistory, FromErr, Http as HttpProvider, JsonRpcClient, JsonRpcClientWrapper, MockProvider,
+    PendingTransaction, QuorumProvider,
 };
 
 use ethers_core::{
@@ -898,6 +899,13 @@ impl Provider<crate::Ipc> {
     }
 }
 
+impl<T: JsonRpcClientWrapper> Provider<QuorumProvider<T>> {
+    /// Provider that uses a quorum
+    pub fn quorum(inner: QuorumProvider<T>) -> Self {
+        Self::new(inner)
+    }
+}
+
 impl Provider<MockProvider> {
     /// Returns a `Provider` instantiated with an internal "mock" transport.
     ///
